@@ -1,10 +1,4 @@
-extern crate assert_cmd;
-extern crate escargot;
-extern crate predicates;
-
-use std::process::Command;
-
-use assert_cmd::prelude::*;
+use assert_cmd::Command;
 
 #[test]
 fn lib_example() {
@@ -12,11 +6,11 @@ fn lib_example() {
     cmd.assert().success();
 
     let mut cmd = Command::cargo_bin("bin_fixture").unwrap();
-    cmd.arg("-A")
+    let assert = cmd
+        .arg("-A")
         .env("stdout", "hello")
         .env("exit", "42")
-        .with_stdin()
-        .buffer("42");
-    let assert = cmd.assert();
+        .write_stdin("42")
+        .assert();
     assert.failure().code(42).stdout("hello\n");
 }
